//! Tests auto-converted from "sass-spec/spec/core_functions/modules"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("modules")
}

mod color;
